@@ -1,9 +1,10 @@
+#' @keywords internal
 get_deactive_index <- function(loon.grob, index, ...) {
   obj <- character(0)
   class(obj) <- names(loon.grob$children)
   UseMethod("get_deactive_index", obj)
 }
-
+#' @keywords internal
 get_deactive_index.l_plot <- function(loon.grob, index, ...) {
 
   args <- list(...)
@@ -88,8 +89,8 @@ get_deactive_index.l_plot <- function(loon.grob, index, ...) {
   } else numeric(0)
 }
 
-
-get_deactive_index.l_hist <- function(loon.grob, index) {
+#' @keywords internal
+get_deactive_index.l_hist <- function(loon.grob, index, ...) {
 
   newGrob <- grid::getGrob(loon.grob, "histogram")
   whichIsDeactive <- numeric(0)
@@ -105,8 +106,8 @@ get_deactive_index.l_hist <- function(loon.grob, index) {
   whichIsDeactive[which(!is.na(whichIsDeactive))]
 }
 
-
-get_deactive_index.l_graph <- function(loon.grob, index) {
+#' @keywords internal
+get_deactive_index.l_graph <- function(loon.grob, index, ...) {
 
   newGrob <- grid::getGrob(loon.grob, "graph nodes")
   whichIsDeactive <- numeric(0)
@@ -121,7 +122,7 @@ get_deactive_index.l_graph <- function(loon.grob, index) {
 
   whichIsDeactive[which(!is.na(whichIsDeactive))]
 }
-
+#' @keywords internal
 get_deactive_index.l_serialaxes <- function(loon.grob, index, ...) {
 
   args <- list(...)
