@@ -1,9 +1,10 @@
+#' @keywords internal
 get_labels <- function(loon.grob) {
   obj <- character(0)
   class(obj) <- names(loon.grob$children)
   UseMethod("get_labels", obj)
 }
-
+#' @keywords internal
 get_labels.default <- function(loon.grob) {
   showLabels <- TRUE
   xlabel_grob <- grid::getGrob(loon.grob, "x label")
@@ -34,7 +35,7 @@ get_labels.default <- function(loon.grob) {
     title = title
   )
 }
-
+#' @keywords internal
 get_labels.l_serialaxes <- function(loon.grob) {
 
   showLabels <- TRUE
@@ -53,13 +54,13 @@ get_labels.l_serialaxes <- function(loon.grob) {
   )
 }
 
-
+#' @keywords internal
 set_labelsGrob <- function(loon.grob, showScales, xlabel, ylabel, title) {
   obj <- character(0)
   class(obj) <- names(loon.grob$children)
   UseMethod("set_labelsGrob", obj)
 }
-
+#' @keywords internal
 set_labelsGrob.default <- function(loon.grob, showScales, xlabel, ylabel, title) {
 
   xylab_loc <- if (showScales) c(-3.5, -6.5) else c(-1, -1)
@@ -117,8 +118,8 @@ set_labelsGrob.default <- function(loon.grob, showScales, xlabel, ylabel, title)
     )
   )
 }
-
-set_labelsGrob.l_serialaxes <- function(loon.grob, title) {
+#' @keywords internal
+set_labelsGrob.l_serialaxes <- function(loon.grob, showScales, xlabel, ylabel, title) {
 
   gPath <- "title"
   titleGrob <- grid::getGrob(loon.grob, gPath)
