@@ -43,24 +43,27 @@ get_linkingInfo <- function(linkingGroups, loonWidgetsInfo,
 }
 
 
-
+#' @keywords internal
 update_linkingInfo <- function(loon.grob,
                                tabPanelName,
                                linkingInfo,
                                linkingGroup,
+                               linkingKey,
                                selected,
                                color,
+                               size,
+                               pch,
                                active,
                                selectByColor,
-                               linkedStates, ...) {
+                               linkedStates) {
   obj <- character(0)
   class(obj) <- names(loon.grob$children)
   UseMethod("update_linkingInfo", obj)
 }
-
+#' @keywords internal
 update_linkingInfo.l_plot <- function(loon.grob,
                                       tabPanelName,
-                                      # they are the central commendar
+                                      # they are the central commander
                                       linkingInfo,
                                       linkingGroup,
                                       # they are `loon.grob`'s aesthetics
@@ -103,13 +106,11 @@ update_linkingInfo.l_plot <- function(loon.grob,
   }
   linkingInfo
 }
-
+#' @keywords internal
 update_linkingInfo.l_graph <- function(loon.grob,
                                        tabPanelName,
-                                       # they are the central commendar
                                        linkingInfo,
                                        linkingGroup,
-                                       # they are `loon.grob`'s aesthetics
                                        linkingKey,
                                        selected,
                                        color,
@@ -135,7 +136,7 @@ update_linkingInfo.l_graph <- function(loon.grob,
                             selectByColor = selectByColor,
                             linkedStates = linkedStates)
 }
-
+#' @keywords internal
 update_linkingInfo.l_serialaxes <- function(loon.grob,
                                             tabPanelName,
                                             linkingInfo,
@@ -143,8 +144,9 @@ update_linkingInfo.l_serialaxes <- function(loon.grob,
                                             linkingKey,
                                             selected,
                                             color,
-                                            active,
                                             size,
+                                            pch,
+                                            active,
                                             selectByColor,
                                             linkedStates) {
 
@@ -174,7 +176,7 @@ update_linkingInfo.l_serialaxes <- function(loon.grob,
   }
   linkingInfo
 }
-
+#' @keywords internal
 update_linkingInfo.l_hist <- function(loon.grob,
                                       tabPanelName,
                                       linkingInfo,
@@ -182,6 +184,8 @@ update_linkingInfo.l_hist <- function(loon.grob,
                                       linkingKey,
                                       selected,
                                       color,
+                                      size,
+                                      pch,
                                       active,
                                       selectByColor,
                                       linkedStates) {
