@@ -1,9 +1,10 @@
+#' @keywords internal
 move_halign_grob <- function(loon.grob, index, swap, halignY, temporary = FALSE, ...) {
   obj <- character(0)
   class(obj) <- names(loon.grob$children)
   UseMethod("move_halign_grob", obj)
 }
-
+#' @keywords internal
 move_halign_grob.l_plot <- function(loon.grob, index, swap, halignY, temporary = FALSE, ...) {
 
   if(length(index) == 0) return(loon.grob)
@@ -203,8 +204,8 @@ move_halign_grob.l_plot <- function(loon.grob, index, swap, halignY, temporary =
     )
   } else loon.grob
 }
-
-move_halign_grob.l_graph <- function(loon.grob, index, swap, halignY, temporary = FALSE) {
+#' @keywords internal
+move_halign_grob.l_graph <- function(loon.grob, index, swap, halignY, temporary = FALSE, ...) {
 
   if(length(index) == 0) return(loon.grob)
 
