@@ -1,9 +1,10 @@
+#' @keywords internal
 move_hdist_grob <- function(loon.grob, index, swap, hdistY, temporary = FALSE, ...) {
   obj <- character(0)
   class(obj) <- names(loon.grob$children)
   UseMethod("move_hdist_grob", obj)
 }
-
+#' @keywords internal
 move_hdist_grob.l_plot <- function(loon.grob, index, swap, hdistY, temporary = FALSE, ...) {
 
   if(length(index) == 0) return(loon.grob)
@@ -211,8 +212,8 @@ move_hdist_grob.l_plot <- function(loon.grob, index, swap, hdistY, temporary = F
     )
   } else loon.grob
 }
-
-move_hdist_grob.l_graph <- function(loon.grob, index, swap, hdistY, temporary = FALSE) {
+#' @keywords internal
+move_hdist_grob.l_graph <- function(loon.grob, index, swap, hdistY, temporary = FALSE, ...) {
 
   if(length(index) == 0) return(loon.grob)
 
