@@ -1,9 +1,10 @@
+#' @keywords internal
 move_valign_grob <- function(loon.grob, index, swap, valignX, temporary = FALSE, ...) {
   obj <- character(0)
   class(obj) <- names(loon.grob$children)
   UseMethod("move_valign_grob", obj)
 }
-
+#' @keywords internal
 move_valign_grob.l_plot <- function(loon.grob, index, swap, valignX, temporary = FALSE, ...) {
 
   if(length(index) == 0) return(loon.grob)
@@ -199,8 +200,8 @@ move_valign_grob.l_plot <- function(loon.grob, index, swap, valignX, temporary =
   } else loon.grob
 }
 
-
-move_valign_grob.l_graph <- function(loon.grob, index, swap, valignX, temporary = FALSE) {
+#' @keywords internal
+move_valign_grob.l_graph <- function(loon.grob, index, swap, valignX, temporary = FALSE, ...) {
 
   if(length(index) == 0) return(loon.grob)
 
