@@ -1,10 +1,11 @@
+#' @keywords internal
 move_vdist_grob <- function(loon.grob, index, swap, vdistX, temporary = FALSE, ...) {
   obj <- character(0)
   class(obj) <- names(loon.grob$children)
   UseMethod("move_vdist_grob", obj)
 }
 
-
+#' @keywords internal
 move_vdist_grob.l_plot <- function(loon.grob, index, swap, vdistX, temporary = FALSE, ...) {
 
   if(length(index) == 0) return(loon.grob)
@@ -211,8 +212,8 @@ move_vdist_grob.l_plot <- function(loon.grob, index, swap, vdistX, temporary = F
     )
   } else loon.grob
 }
-
-move_vdist_grob.l_graph <- function(loon.grob, index, swap, vdistX, temporary = FALSE) {
+#' @keywords internal
+move_vdist_grob.l_graph <- function(loon.grob, index, swap, vdistX, temporary = FALSE, ...) {
 
   if(length(index) == 0) return(loon.grob)
 
