@@ -1,9 +1,10 @@
+#' @keywords internal
 reorder_grob <- function(loon.grob, number = NULL, index, ...) {
   obj <- character(0)
   class(obj) <- names(loon.grob$children)
   UseMethod("reorder_grob", obj)
 }
-
+#' @keywords internal
 reorder_grob.l_plot <- function(loon.grob, number = NULL, index, ...) {
 
   if(length(index) == 0) return(loon.grob)
@@ -23,8 +24,8 @@ reorder_grob.l_plot <- function(loon.grob, number = NULL, index, ...) {
     )
   )
 }
-
-reorder_grob.l_graph <- function(loon.grob, number = NULL, index) {
+#' @keywords internal
+reorder_grob.l_graph <- function(loon.grob, number = NULL, index, ...) {
 
   if(length(index) == 0) return(loon.grob)
 
@@ -41,7 +42,7 @@ reorder_grob.l_graph <- function(loon.grob, number = NULL, index) {
   )
 }
 
-
+#' @keywords internal
 reorder_grob.l_serialaxes <- function(loon.grob, number = NULL, index, ...) {
 
   if(length(index) == 0) return(loon.grob)
