@@ -1,9 +1,10 @@
+#' @keywords internal
 set_deactive_grob <- function(loon.grob, index, ...) {
   obj <- character(0)
   class(obj) <- names(loon.grob$children)
   UseMethod("set_deactive_grob", obj)
 }
-
+#' @keywords internal
 set_deactive_grob.l_plot <- function(loon.grob, index, ...) {
 
   args <- list(...)
@@ -74,7 +75,7 @@ set_deactive_grob.l_plot <- function(loon.grob, index, ...) {
   }
 }
 
-
+#' @keywords internal
 set_deactive_grob.l_hist <- function(loon.grob, index, ...) {
 
   if(length(index) >0) {
@@ -99,8 +100,8 @@ set_deactive_grob.l_hist <- function(loon.grob, index, ...) {
     loon.grob
   }
 }
-
-set_deactive_grob.l_graph <- function(loon.grob, index) {
+#' @keywords internal
+set_deactive_grob.l_graph <- function(loon.grob, index, ...) {
 
   if(length(index) > 0) {
 
@@ -175,7 +176,7 @@ set_deactive_grob.l_graph <- function(loon.grob, index) {
   }
 }
 
-
+#' @keywords internal
 set_deactive_grob.l_serialaxes <- function(loon.grob, index, ...) {
 
   if(length(index) > 0) {
