@@ -1,9 +1,12 @@
-update_limitSliderInput <- function(loon.grob, ...) {
+#' @keywords internal
+update_limitSliderInput <- function(loon.grob, loonWidgetsInfo, input, session, buttons, tabPanelName,
+                                    brushId) {
   obj <- character(0)
   class(obj) <- names(loon.grob$children)
   UseMethod("update_limitSliderInput", obj)
 }
 
+#' @keywords internal
 update_limitSliderInput.default <- function(loon.grob, loonWidgetsInfo, input, session, buttons, tabPanelName,
                                             brushId) {
 
@@ -203,8 +206,8 @@ update_limitSliderInput.default <- function(loon.grob, loonWidgetsInfo, input, s
     )
   }
 }
-
-update_limitSliderInput.l_hist <- function(loon.grob, loonWidgetsInfo, input, session, buttons, tabPanelName) {
+#' @keywords internal
+update_limitSliderInput.l_hist <- function(loon.grob, loonWidgetsInfo, input, session, buttons, tabPanelName, brushId) {
 
   swapInLoon <- loonWidgetsInfo$swapInLoon
   swapInShiny <- "swap" %in% input[[paste0(tabPanelName, "plotAxes1")]]
